====================
Module - reportentry
====================


This module provides for the following ansible plugin:

    * reportentry


.. ansibleautoplugin::
   :module: validations_common/library/reportentry.py
   :documentation: true
   :examples: true
